@@ -109,6 +109,13 @@ extern "C" int ctrl_c_interrupted(int exception);
 extern "C" void console_print(const char * s);
 extern "C" const char * console_prompt(const char * s);
 
+bool dfu_get_scriptstore_addr(size_t & start,size_t & taille);
+bool dfu_get_scriptstore(const char * fname);
+bool dfu_send_scriptstore(const char * fname);
+const int nwstoresize1=0x8000,nwstoresize2=0x8014;
+bool dfu_send_firmware(const char * fname);
+bool dfu_send_apps(const char * fname);
+
 #if defined HAVE_LIBMICROPYTHON
 #include <string>
 // giac interface to micropython modules
@@ -518,6 +525,14 @@ throw(std::runtime_error("Stopped by user interruption.")); \
   typedef std::map<const char *, gen,ltstr> map_charptr_gen;
   typedef map_charptr_gen sym_tab;
 
+  struct nwsrec {
+    unsigned char type;
+    std::vector<unsigned char> data;
+  };
+  typedef std::map<std::string,nwsrec,ltstring> nws_map;
+  bool scriptstore2map(const char * fname,nws_map & m);
+  bool map2scriptstore(const nws_map & m,const char * fname);
+
   struct parser_lexer {
     int _index_status_; // 0 if [ -> T_VECT_DISPATCH, 1 if [ -> T_INDEX_BEGIN
     int _opened_quote_; // 1 if we are inside a quote
